// Fragment shader for drawing the Mandelbrot set
// Adapted from Orange book

varying vec3  ModelPos;
varying float LightIntensity;

// Center and zoom for mandelbrot set
uniform float Zoom;
uniform float Xcenter;
uniform float Ycenter;
// Maximum number of iterations
const float MaxIterations = 100.0;
//  Colors
const vec3  InnerColor  = {0.0,0.0,0.0};
const vec3  OuterColor1 = {1.0,0.0,0.0};
const vec3  OuterColor2 = {0.0,1.0,0.0};

void main()
{
   //  Initialize
   float real  = ModelPos.x * Zoom + Xcenter;
   float imag  = ModelPos.y * Zoom + Ycenter;
   float Creal = real;
   float Cimag = imag;

   //  Iterate
   float r2 = 0.0;
   float iter;
   for (iter=0.0 ; iter<MaxIterations && r2 < 4.0 ; iter++)
   {
       float tempreal = real;
       real = (tempreal * tempreal) - (imag * imag) + Creal;
       imag = 2.0 * tempreal * imag + Cimag;
       r2   = (real * real) + (imag * imag);
   }

   // Base the color on the number of iterations
   vec3 color = (r2 < 4.0) ? InnerColor : mix(OuterColor1,OuterColor2,fract(0.01*iter));
   color *= LightIntensity;
   gl_FragColor = vec4(color, 1.0);
}
